/*
 * File:                EstimableWeightedDistribution.java
 * Authors:             Kevin R. Dixon
 * Company:             Sandia National Laboratories
 * Project:             Cognitive Foundry
 * 
 * Copyright Jan 30, 2012, Sandia Corporation.
 * Under the terms of Contract DE-AC04-94AL85000, there is a non-exclusive
 * license for use of this work by or on behalf of the U.S. Government.
 * Export of this program may require a license from the United States
 * Government. See CopyrightHistory.txt for complete details.
 * 
 */

package gov.sandia.cognition.statistics;

/**
 * A Distribution that has an estimator associated with it, typically a
 * closed-form estimator, that can estimate the distribution from weighted data.
 * @param <ObservationType>
 * Type of observations generated by the Distribution.
 * @param <DistributionType>
 * Type of distribution returned from the DistributionWeightedEstimator.
 * @author Kevin R. Dixon
 * @since  3.4.2
 */
public interface EstimableWeightedDistribution<ObservationType,DistributionType extends EstimableWeightedDistribution<ObservationType,? extends DistributionType>>
    extends EstimableDistribution<ObservationType,DistributionType>
{

    /**
     * Gets an estimator associated with this distribution for weighted data
     * 
     * @return
     *      A distribution estimator associated for this distribution.
     */
    public DistributionWeightedEstimator<ObservationType,? extends DistributionType> getWeightedEstimator();
    
}
